summaryrefslogtreecommitdiff
path: root/decorators.py
diff options
context:
space:
mode:
authorSylvain <syt@logilab.fr>2008-02-07 18:52:34 +0100
committerSylvain <syt@logilab.fr>2008-02-07 18:52:34 +0100
commitb18f6dfb8a50bc641c860dfa10b5c12361b6620c (patch)
tree5b2b91a6a1fc25814543cc504296e0462e9ada92 /decorators.py
parent3537e4f8ab1d5823f73702e2c1b57d728c59f344 (diff)
downloadlogilab-common-b18f6dfb8a50bc641c860dfa10b5c12361b6620c.tar.gz
configuration: fix merge_options
Diffstat (limited to 'decorators.py')
-rw-r--r--decorators.py11
1 files changed, 7 insertions, 4 deletions
diff --git a/decorators.py b/decorators.py
index 7cf5a6c..fb9c818 100644
--- a/decorators.py
+++ b/decorators.py
@@ -1,6 +1,3 @@
-# Copyright (c) 2006-2007 LOGILAB S.A. (Paris, FRANCE).
-# http://www.logilab.fr/ -- mailto:contact@logilab.fr
-#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
@@ -13,7 +10,13 @@
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-"""this module contains some function/method decorators"""
+"""this module contains some function/method decorators
+
+:author: Logilab
+:copyright: 2006-2008 LOGILAB S.A. (Paris, FRANCE)
+:contact: http://www.logilab.fr/ -- mailto:python-projects@logilab.org
+"""
+__docformat__ = "restructuredtext en"
# XXX rewrite so we can use the decorator syntax when keyarg has to be specified